<?php
/*
Plugin Name: Super Zoom Gallery
Plugin URI: http://blog.leitmotif.nl/super-zoom-gallery/
Description: Gallery plugin with thumbnail and zoom capabilities, great for showing details of photos. Easy to use. Great for webshops!
Version: 0.4.5
Author: Niels Doorn
Author URI: http://blog.leitmotif.nl
License: GPL2
*/

/*  Copyright 2012  Niels Doorn  (email : szg@leitmotif.nl)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

global $superZoomGallery;
$superZoomGallery = new SuperZoomGallery();
register_activation_hook( __FILE__, array(&$superZoomGallery,'activate' ));
register_deactivation_hook( __FILE__, array(&$superZoomGallery,'deactivate' ));
add_filter('plugin_action_links', array(&$superZoomGallery, 'add_settings_link'), 10, 2 );


class SuperZoomGallery {
	
	public $updated_message = '';
	
	function __construct() {
		add_shortcode('superzoomgallery', array(&$this, 'generate_gallery'));
		if (get_option('superzoomgallery_overwrite_gallery') == 'enabled') {
			add_shortcode('gallery', array(&$this, 'generate_gallery'));
		}
		
		
		wp_enqueue_script('jquery');
		wp_enqueue_script('jquery');
		wp_register_script('zoomer', WP_PLUGIN_URL . '/super-zoom-gallery/zoomer.jquery.js', array('jquery'), null, true);
		//wp_register_script('zoomer', WP_PLUGIN_URL . '/super-zoom-gallery/zoomer.jquery.js');
		wp_enqueue_script('zoomer');
		
		wp_register_style('superzoomgallerystylesheet', WP_PLUGIN_URL . '/super-zoom-gallery/superzoomgallery.css');
		wp_enqueue_style('superzoomgallerystylesheet');	
		
		if (get_option('superzoomgallery_usecss3', 'disabled') != 'disabled') {
			wp_register_style('superzoomgallerystylesheetanimations', WP_PLUGIN_URL . '/super-zoom-gallery/animations.css');
			wp_enqueue_style('superzoomgallerystylesheetanimations');
		
			wp_register_script('prefix-free', WP_PLUGIN_URL . '/super-zoom-gallery/prefixfree.min.js');
			wp_enqueue_script('prefix-free');
		}
		
		add_action('admin_menu', array(&$this,'add_admin_menu'), 0);
	}
	
	function activate() {
		add_option("superzoomgallery_thumb", 'thumbnail', 'What image to use for the gallery thumbnails', 'yes');
		add_option("superzoomgallery_medium", 'medium', 'What image to use for the gallery medium size image', 'yes');
		add_option("superzoomgallery_full", 'full', 'What image to use for the gallery zoomed in image', 'yes');
		add_option("superzoomgallery_overwrite_gallery", 'disabled', 'Overwrite the default gallery shortcode or not', 'yes');
		add_option("superzoomgallery_showcaptions", 'disabled', 'Show captions on the mediumsize image and the thumbnails or not', 'yes');
		add_option("superzoomgallery_captionfield", 'title', 'What field to use as a caption', 'yes');
		add_option("superzoomgallery_usecss3", 'disabled', 'Use CSS3 features', 'yes');
	}
	
	function deactivate() {
		delete_option("superzoomgallery_thumb");
		delete_option("superzoomgallery_medium");
		delete_option("superzoomgallery_full");
		delete_option("superzoomgallery_overwrite_gallery");
		delete_option("superzoomgallery_showcaptions");
		delete_option("superzoomgallery_captionfield");
		delete_option("superzoomgallery_usecss3");
	}
	
	public function add_admin_menu() {
		add_options_page('Super zoom gallery Options', 'Super zoom gallery', 'manage_options', 'superzoomgallery', array(&$this, 'settings_page'));
  	}
  	
 	public function add_settings_link($links, $file) {
		static $this_plugin;
		if (!$this_plugin) $this_plugin = plugin_basename(__FILE__);
		if ($file == $this_plugin) {
			$settings_link = '<a href="options-general.php?page=superzoomgallery">'.__("Settings", "Super Zoom Gallery").'</a>';
	 		array_unshift($links, $settings_link);
	 		$faq_link = '<a href="http://wordpress.org/extend/plugins/super-zoom-gallery/">'.__("Wordpress page", "Super Zoom Gallery").'</a>';
	 		array_unshift($links, $faq_link);
		}
		return $links;
	 }

  
	public function settings_page() {
	   $this->save_settings_page();
	   include('superzoomgallery-admin-settings.php');
	}
	
	 public function save_settings_page() {
	    if (isset($_POST['superzoomgallery_thumb'] )) {
	      update_option('superzoomgallery_thumb', $_POST['superzoomgallery_thumb']);
		  update_option('superzoomgallery_medium', $_POST['superzoomgallery_medium']);
	      update_option('superzoomgallery_full', $_POST['superzoomgallery_full']);
	      $overwriteDefaultGallery = isset($_POST['superzoomgallery_overwrite_gallery']) ? 'enabled' : 'disabled';
	      update_option('superzoomgallery_overwrite_gallery', $overwriteDefaultGallery);
		  $showCaptions= isset($_POST['superzoomgallery_showcaptions']) ? 'enabled' : 'disabled';
	      update_option('superzoomgallery_showcaptions', $showCaptions);
	
		  update_option('superzoomgallery_captionfield', $_POST['superzoomgallery_captionfield']);
	
		  $useCss3= isset($_POST['superzoomgallery_usecss3']) ? 'enabled' : 'disabled';
	      update_option('superzoomgallery_usecss3', $useCss3);
	      $this->updated_message = 'Settings saved!';
	    }
	 }

	
	public function generate_gallery($atts, $the_content = null) {
	  global $post;
	  $content = '';
	  $files = get_children('post_parent='.$post->ID.'&post_type=attachment&post_mime_type=image&orderby=menu_order');
	  if($files) :
	    $keys = array_reverse(array_keys($files));
	    $j=0;
	    $jscript = '<script type="text/javascript">'."\n"; 
	    $jscript .= 'jQuery(function ($) {'."\n";
	   	$jscript .= '$(document).ready(function() { '."\n";
	    $thumbhtml = ''."\n";
	    $thumbhtml .= '<div id="gal-thumbnails-'.$post->ID.'">'."\n";
	    $content .= '<div id="gal-uberwrap-'.$post->ID.'">'."\n";
	    foreach ($keys as $num) {
			$file = $files[$num];
			
			$fieldToUse = get_option('superzoomgallery_captionfield', 'title');
			if ('caption' == $fieldToUse) {
				$caption = $file->post_excerpt;
			} else {
				$caption = $file->post_title;
			}
			
	    	$big 	= 	wp_get_attachment_image_src($num, get_option('superzoomgallery_full', 'full'), false);
		    $medium	=	wp_get_attachment_image_src($num,  get_option('superzoomgallery_medium', 'medium'), false);
		    $thumb	=	wp_get_attachment_image_src($num,  get_option('superzoomgallery_thumb', 'thumbnail'), false);
		    $content .= '<div id="gal-wrap-'.$post->ID.'-'.$num.'" class="gal-wrap-'.$post->ID.' gal-wrap" style="height:'.($medium[2]).'px">'."\n";
		    $content .= '	<div id="gal-small-'.$post->ID.'-'.$num.'" class="gal-small">'."\n";
		    $content .= '  	  <img id="gal-img-'.$post->ID.'-'.$num.'" class="gal-img" src="'.$medium[0].'" />'."\n";
			if ($caption && get_option('superzoomgallery_showcaptions', '') != 'disabled') {
				$content .= '    <div class="imageinfobig" style="width:'.$medium[1].'px">'.$caption.'</div>'."\n";
			}
		    $content .= '  </div>'."\n";
		    $content .= '  <div class="zoom-box" id="gal-overlay-'.$post->ID.'-'.$num.'">'."\n";
		    $content .= '    <div id="gal-mover-'.$post->ID.'-'.$num.'" class="gal-mover" style="max-height:'.($medium[2]).'px">'."\n";
		    $content .= '      <div id="gal-large-'.$post->ID.'-'.$num.'" class="gal-large">'."\n";
		    $content .= '        <img style="max-width: none;" class="gal-large-image" src="'.$big[0].'"/>'."\n";                    
		    $content .= '      </div>'."\n";
		    $content .= '    </div>'."\n";
		    $content .= '  </div>'."\n";
		 	$content .= '</div>'."\n";
		 	$thumbhtml .= '<div class="gal-thumbnail-'.$post->ID.' gal-thumbnail" onClick="selectImage(this,\'gal-wrap-'.$post->ID.'-'.$num.'\','.$post->ID.');">'."\n";
	   		$thumbhtml .= '	<img src="'.$thumb[0].'" />'."\n";
			if ($caption && get_option('superzoomgallery_showcaptions', '') != 'disabled') {
				$thumbhtml .= '    <div class="imageinfosmall" style="width:'.$thumb[1].'px">'.$caption.'</div>'."\n";
			}
	   		$thumbhtml .= '</div>'."\n";
	   		$jscript .= '$("#gal-wrap-'.$post->ID.'-'.$num.'").anythingZoomer({'."\n";
	    	$jscript .= '    smallArea: "#gal-img-'.$post->ID.'-'.$num.'",'."\n";
	        $jscript .= '    largeArea: "#gal-large-'.$post->ID.'-'.$num.'",'."\n";
	        $jscript .= '    zoomPort: "#gal-overlay-'.$post->ID.'-'.$num.'",'."\n";
	        $jscript .= '    mover: "#gal-mover-'.$post->ID.'-'.$num.'",'."\n";
	        $jscript .= '    xSpeedMultiplier: '.($big[1]/$medium[1]).','."\n";
	        $jscript .= '    ySpeedMultiplier: '.($big[2]/$medium[2]).','."\n";
	        $jscript .= '    smallImageWidth: '.($medium[1]).','."\n";
	        $jscript .= '    smallImageHeight: '.($medium[2]).','."\n";
	        $jscript .= '    largeImageWidth: '.($big[1]).','."\n";
	        $jscript .= '    largeImageHeight: '.($big[2])."\n";
	    	$jscript .= '});'."\n";
	    }
	    $content .= '</div>'."\n";
	    $thumbhtml .= '</div>'."\n";
	    $jscript .= 'selectImage($(\'.gal-thumbnail-'.$post->ID.':first\'), $(\'.gal-wrap-'.$post->ID.':first\').attr(\'id\'), '.$post->ID.');'."\n";
	    $jscript .= '});'."\n";
	    $jscript .= '});'."\n";
	    $jscript .= '</script>'."\n";
	    if(count($files) > 1) {    
			$content .= $thumbhtml;
		}
	    $content .= $jscript;
	  endif;  
	  return $content;
	}
}
?>
